[Openmp-commits] [openmp] r209995 - Fix typos

Alp Toker alp at nuanti.com
Sun Jun 1 11:28:36 PDT 2014


Author: alp
Date: Sun Jun  1 13:28:36 2014
New Revision: 209995

URL: http://llvm.org/viewvc/llvm-project?rev=209995&view=rev
Log:
Fix typos

Modified:
    openmp/trunk/offload/doc/doxygen/config
    openmp/trunk/offload/src/cean_util.cpp
    openmp/trunk/offload/src/cean_util.h
    openmp/trunk/offload/src/coi/coi_client.h
    openmp/trunk/offload/src/coi/coi_server.h
    openmp/trunk/offload/src/compiler_if_host.cpp
    openmp/trunk/offload/src/offload_engine.h
    openmp/trunk/offload/src/offload_env.cpp
    openmp/trunk/offload/src/offload_host.cpp
    openmp/trunk/offload/src/offload_host.h
    openmp/trunk/testsuite/c/omp_barrier.c
    openmp/trunk/testsuite/c/omp_for_schedule_guided.c
    openmp/trunk/testsuite/c/omp_parallel_for_if.c
    openmp/trunk/testsuite/c/omp_parallel_for_private.c
    openmp/trunk/testsuite/c/omp_parallel_sections_private.c
    openmp/trunk/testsuite/c/omp_single.c
    openmp/trunk/testsuite/c/omp_task.c
    openmp/trunk/testsuite/c/omp_task_final.c
    openmp/trunk/testsuite/fortran/do_schedule_guided.f
    openmp/trunk/testsuite/fortran/omp_barrier.f
    openmp/trunk/testsuite/fortran/omp_num_threads.f
    openmp/trunk/testsuite/fortran/omp_single.f
    openmp/trunk/testsuite/ompts_parser.pl
    openmp/trunk/testsuite/ompts_standaloneProc.f

Modified: openmp/trunk/offload/doc/doxygen/config
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/doc/doxygen/config?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/doc/doxygen/config (original)
+++ openmp/trunk/offload/doc/doxygen/config Sun Jun  1 13:28:36 2014
@@ -1972,7 +1972,7 @@ PREDEFINED             = COI_LIBRARY_VER
 EXPAND_AS_DEFINED      = 
 
 # If the SKIP_FUNCTION_MACROS tag is set to YES then doxygen's preprocessor will
-# remove all refrences to function-like macros that are alone on a line, have an
+# remove all references to function-like macros that are alone on a line, have an
 # all uppercase name, and do not end with a semicolon. Such function macros are
 # typically used for boiler-plate code, and will confuse the parser if not
 # removed.

Modified: openmp/trunk/offload/src/cean_util.cpp
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/cean_util.cpp?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/cean_util.cpp (original)
+++ openmp/trunk/offload/src/cean_util.cpp Sun Jun  1 13:28:36 2014
@@ -60,7 +60,7 @@ CeanReadRanges * init_read_ranges_arr_de
     return res;
 }
 
-// check if ranges described by 1 argument could be transfered into ranges
+// check if ranges described by 1 argument could be transferred into ranges
 // described by 2-nd one
 bool cean_ranges_match(
     CeanReadRanges * read_rng1,

Modified: openmp/trunk/offload/src/cean_util.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/cean_util.h?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/cean_util.h (original)
+++ openmp/trunk/offload/src/cean_util.h Sun Jun  1 13:28:36 2014
@@ -60,7 +60,7 @@ bool is_arr_desc_contiguous(const arr_de
 // to read consequently contiguous ranges described by "ap" argument
 CeanReadRanges * init_read_ranges_arr_desc(const arr_desc *ap);
 
-// check if ranges described by 1 argument could be transfered into ranges
+// check if ranges described by 1 argument could be transferred into ranges
 // described by 2-nd one
 bool cean_ranges_match(
     CeanReadRanges * read_rng1,
@@ -75,7 +75,7 @@ bool get_next_range(
     int64_t *offset
 );
 
-// returns number of transfered bytes
+// returns number of transferred bytes
 int64_t cean_get_transf_size(CeanReadRanges * read_rng);
 
 #if OFFLOAD_DEBUG > 0

Modified: openmp/trunk/offload/src/coi/coi_client.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/coi/coi_client.h?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/coi/coi_client.h (original)
+++ openmp/trunk/offload/src/coi/coi_client.h Sun Jun  1 13:28:36 2014
@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 
 
-// The interface betwen offload library and the COI API on the host
+// The interface between offload library and the COI API on the host
 
 #ifndef COI_CLIENT_H_INCLUDED
 #define COI_CLIENT_H_INCLUDED

Modified: openmp/trunk/offload/src/coi/coi_server.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/coi/coi_server.h?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/coi/coi_server.h (original)
+++ openmp/trunk/offload/src/coi/coi_server.h Sun Jun  1 13:28:36 2014
@@ -8,7 +8,7 @@
 //===----------------------------------------------------------------------===//
 
 
-//The interface betwen offload library and the COI API on the target.
+//The interface between offload library and the COI API on the target.
 
 #ifndef COI_SERVER_H_INCLUDED
 #define COI_SERVER_H_INCLUDED

Modified: openmp/trunk/offload/src/compiler_if_host.cpp
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/compiler_if_host.cpp?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/compiler_if_host.cpp (original)
+++ openmp/trunk/offload/src/compiler_if_host.cpp Sun Jun  1 13:28:36 2014
@@ -52,7 +52,7 @@ extern "C" OFFLOAD OFFLOAD_TARGET_ACQUIR
 
     OFFLOAD_TIMER_START(timer_data, c_offload_host_initialize);
 
-    // initalize all devices is init_type is on_offload_all
+    // initialize all devices is init_type is on_offload_all
     if (retval && __offload_init_type == c_init_on_offload_all) {
         for (int i = 0; i < mic_engines_total; i++) {
              mic_engines[i].init();

Modified: openmp/trunk/offload/src/offload_engine.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/offload_engine.h?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/offload_engine.h (original)
+++ openmp/trunk/offload/src/offload_engine.h Sun Jun  1 13:28:36 2014
@@ -214,7 +214,7 @@ struct PersistData
     {
         stack_ptr_data = new PtrData(0, size);
     }
-    // 1-st key value - begining of the stack at CPU
+    // 1-st key value - beginning of the stack at CPU
     const void *   stack_cpu_addr;
     // 2-nd key value - identifier of routine invocation at CPU
     uint64_t   routine_id;

Modified: openmp/trunk/offload/src/offload_env.cpp
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/offload_env.cpp?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/offload_env.cpp (original)
+++ openmp/trunk/offload/src/offload_env.cpp Sun Jun  1 13:28:36 2014
@@ -126,7 +126,7 @@ void MicEnvVar::add_env_var(
     else {
         card = get_card(card_number);
         if (!card) {
-            // definition for new card occured
+            // definition for new card occurred
             card = new CardEnvVars(card_number);
             card_spec_list.push_back(card);
         }
@@ -299,7 +299,7 @@ void MicEnvVar::mic_parse_env_var_list(
 // Collect all definitions for the card with number "card_num".
 // The returned result is vector of string pointers defining one
 // environment variable. The vector is terminated by NULL pointer.
-// In the begining of the vector there are env vars defined as
+// In the beginning of the vector there are env vars defined as
 // <mic-prefix>_<card-number>_<var>=<value>
 // or
 // <mic-prefix>_<card-number>_ENV=<env-vars>

Modified: openmp/trunk/offload/src/offload_host.cpp
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/offload_host.cpp?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/offload/src/offload_host.h (original)
+++ openmp/trunk/offload/src/offload_host.h Sun Jun  1 13:28:36 2014
@@ -107,7 +107,7 @@ private:
         PtrData* src_buf,
         PtrData* dst_buf,
         COIEVENT *event);
-    bool recieve_noncontiguous_pointer_data(
+    bool receive_noncontiguous_pointer_data(
         int i,
         char* src_data,
         COIBUFFER dst_buf,

Modified: openmp/trunk/testsuite/c/omp_barrier.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_barrier.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_barrier.c (original)
+++ openmp/trunk/testsuite/c/omp_barrier.c Sun Jun  1 13:28:36 2014
@@ -1,5 +1,5 @@
 <ompts:test>
-<ompts:testdescription>Test which checks the omp barrier directive. The test creates several threads and sends one of them sleeping before setting a flag. After the barrier the other ones do some littel work depending on the flag.</ompts:testdescription>
+<ompts:testdescription>Test which checks the omp barrier directive. The test creates several threads and sends one of them sleeping before setting a flag. After the barrier the other ones do some little work depending on the flag.</ompts:testdescription>
 <ompts:ompversion>2.0</ompts:ompversion>
 <ompts:directive>omp barrier</ompts:directive>
 <ompts:testcode>

Modified: openmp/trunk/testsuite/c/omp_for_schedule_guided.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_for_schedule_guided.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_for_schedule_guided.c (original)
+++ openmp/trunk/testsuite/c/omp_for_schedule_guided.c Sun Jun  1 13:28:36 2014
@@ -214,7 +214,7 @@ int <ompts:testcode:functionname>omp_for
 		  fprintf (logFile, "Chunksize did not decrease: %d instead of %d\n", chunksizes[i],expected_chunk_size);
 #endif
 
-		/* calculating the remaining ammount of work */
+		/* calculating the remaining amount of work */
 		openwork -= chunksizes[i];
 	  }	
 	}

Modified: openmp/trunk/testsuite/c/omp_parallel_for_if.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_parallel_for_if.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_parallel_for_if.c (original)
+++ openmp/trunk/testsuite/c/omp_parallel_for_if.c Sun Jun  1 13:28:36 2014
@@ -33,6 +33,6 @@ int <ompts:testcode:functionname>omp_par
     known_sum = (LOOPCOUNT * (LOOPCOUNT + 1)) / 2;
     fprintf (logFile, "Number of threads determined by omp_get_num_threads: %d\n", num_threads);
     return (known_sum == sum && num_threads == 1);
-} /* end of check_paralel_for_private */
+} /* end of check_parallel_for_private */
 </ompts:testcode>
 </ompts:test>

Modified: openmp/trunk/testsuite/c/omp_parallel_for_private.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_parallel_for_private.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_parallel_for_private.c (original)
+++ openmp/trunk/testsuite/c/omp_parallel_for_private.c Sun Jun  1 13:28:36 2014
@@ -43,6 +43,6 @@ int <ompts:testcode:functionname>omp_par
 
     known_sum = (LOOPCOUNT * (LOOPCOUNT + 1)) / 2;
     return (known_sum == sum);
-} /* end of check_paralel_for_private */
+} /* end of check_parallel_for_private */
 </ompts:testcode>
 </ompts:test>

Modified: openmp/trunk/testsuite/c/omp_parallel_sections_private.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_parallel_sections_private.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_parallel_sections_private.c (original)
+++ openmp/trunk/testsuite/c/omp_parallel_sections_private.c Sun Jun  1 13:28:36 2014
@@ -56,7 +56,7 @@ int <ompts:testcode:functionname>omp_par
 	sum= sum+sum0;
       }                         /*end of critical */
     }               
-  }        /*end of paralell sections*/
+  }        /*end of parallel sections*/
 </ompts:orphan>
 known_sum=(999*1000)/2+7;
 return (known_sum==sum); 

Modified: openmp/trunk/testsuite/c/omp_single.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_single.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_single.c (original)
+++ openmp/trunk/testsuite/c/omp_single.c Sun Jun  1 13:28:36 2014
@@ -1,5 +1,5 @@
 <ompts:test>
-<ompts:testdescription>Test which checks the omp single directive by controling how often a directive is called in an omp single region.</ompts:testdescription>
+<ompts:testdescription>Test which checks the omp single directive by controlling how often a directive is called in an omp single region.</ompts:testdescription>
 <ompts:ompversion>2.0</ompts:ompversion>
 <ompts:directive>omp single</ompts:directive>
 <ompts:dependences>omp parallel private,omp flush</ompts:dependences>

Modified: openmp/trunk/testsuite/c/omp_task.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_task.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_task.c (original)
+++ openmp/trunk/testsuite/c/omp_task.c Sun Jun  1 13:28:36 2014
@@ -47,6 +47,6 @@ int <ompts:testcode:functionname>omp_tas
             return 1;
     }
     return 0;
-} /* end of check_paralel_for_private */
+} /* end of check_parallel_for_private */
 </ompts:testcode>
 </ompts:test>

Modified: openmp/trunk/testsuite/c/omp_task_final.c
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/c/omp_task_final.c?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/c/omp_task_final.c (original)
+++ openmp/trunk/testsuite/c/omp_task_final.c Sun Jun  1 13:28:36 2014
@@ -47,6 +47,6 @@ int <ompts:testcode:functionname>omp_tas
             error++;
     }
     return (error==0);
-} /* end of check_paralel_for_private */
+} /* end of check_parallel_for_private */
 </ompts:testcode>
 </ompts:test>

Modified: openmp/trunk/testsuite/fortran/do_schedule_guided.f
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/fortran/do_schedule_guided.f?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/fortran/do_schedule_guided.f (original)
+++ openmp/trunk/testsuite/fortran/do_schedule_guided.f Sun Jun  1 13:28:36 2014
@@ -7,7 +7,7 @@
   ! TODO:
   ! C. Niethammer:
   !       Find check to decide if the test was run as schedule(static) because
-  !       this also can pass the test if the work is devided into thread-counts 
+  !       this also can pass the test if the work is divided into thread-counts 
       INTEGER FUNCTION <ompts:testcode:functionname>do_schedule_guided</ompts:testcode:functionname>()
         IMPLICIT NONE
         INTEGER omp_get_thread_num,omp_get_num_threads

Modified: openmp/trunk/testsuite/fortran/omp_barrier.f
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/fortran/omp_barrier.f?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/fortran/omp_barrier.f (original)
+++ openmp/trunk/testsuite/fortran/omp_barrier.f Sun Jun  1 13:28:36 2014
@@ -1,5 +1,5 @@
 <ompts:test>
-<ompts:testdescription>Test which checks the omp barrier directive. The test    creates several threads and sends one of them sleeping before setting a flag.  After the barrier the other ones do some littel work depending on the flag.</   ompts:testdescription>
+<ompts:testdescription>Test which checks the omp barrier directive. The test    creates several threads and sends one of them sleeping before setting a flag.  After the barrier the other ones do some little work depending on the flag.</   ompts:testdescription>
 <ompts:ompversion>2.0</ompts:ompversion>
 <ompts:directive>omp barrier</ompts:directive>
 <ompts:testcode>

Modified: openmp/trunk/testsuite/fortran/omp_num_threads.f
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/fortran/omp_num_threads.f?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/fortran/omp_num_threads.f (original)
+++ openmp/trunk/testsuite/fortran/omp_num_threads.f Sun Jun  1 13:28:36 2014
@@ -24,7 +24,7 @@
 
 !Yi Wen added omp_Set_dynamics here to make sure num_threads clause work
 !Thanks to Dr. Yin Ma in Absoft. should be not be called before the test loop
-!becuase it allows the dynamic adjustment of the number of threads at runtime
+!because it allows the dynamic adjustment of the number of threads at runtime
 !instead of using the max_threads set. 
 
         !CALL OMP_SET_DYNAMIC(.TRUE.)

Modified: openmp/trunk/testsuite/fortran/omp_single.f
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/fortran/omp_single.f?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/fortran/omp_single.f (original)
+++ openmp/trunk/testsuite/fortran/omp_single.f Sun Jun  1 13:28:36 2014
@@ -1,5 +1,5 @@
 <ompts:test>
-<ompts:testdescription>Test which checks the omp single directive by controling how often a directive is called in an omp single region.</ompts:testdescription>
+<ompts:testdescription>Test which checks the omp single directive by controlling how often a directive is called in an omp single region.</ompts:testdescription>
 <ompts:ompversion>2.0</ompts:ompversion>
 <ompts:directive>omp single</ompts:directive>
 <ompts:dependences>omp parallel private,omp flush</ompts:dependences>

Modified: openmp/trunk/testsuite/ompts_parser.pl
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/ompts_parser.pl?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/ompts_parser.pl (original)
+++ openmp/trunk/testsuite/ompts_parser.pl Sun Jun  1 13:28:36 2014
@@ -131,7 +131,7 @@ foreach $testtype (@testtypes)
 	$code = "#include \"omp_testsuite.h\"\n".$orphvarsdef . $orphfuncsdefs . $code . $orphfuncs;
       }
       else {
-	print "An error occured!";
+	print "An error occurred!";
       }
     }
 # remove parameters between <ompts:orphan:parms> tags, added by joon

Modified: openmp/trunk/testsuite/ompts_standaloneProc.f
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/testsuite/ompts_standaloneProc.f?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================
--- openmp/trunk/testsuite/ompts_standaloneProc.f (original)
+++ openmp/trunk/testsuite/ompts_standaloneProc.f Sun Jun  1 13:28:36 2014
@@ -44,7 +44,7 @@
       DO j = 1, N
         temp =  <testfunctionname></testfunctionname>()
         IF (temp .EQ. 1) THEN
-          WRITE (1,*)  j, ". test successfull."
+          WRITE (1,*)  j, ". test successful."
           success = success + 1
         ELSE
           WRITE (1,*) "Error: ",j, ". test failed."





More information about the Openmp-commits mailing list
--- openmp/trunk/offload/src/offload_host.cpp (original)
+++ openmp/trunk/offload/src/offload_host.cpp Sun Jun  1 13:28:36 2014
@@ -2290,7 +2290,7 @@ bool OffloadDescriptor::is_signaled()
 
 // Send pointer data if source or destination or both of them are
 // noncontiguous. There is guarantee that length of destination enough for
-// transfered data.
+// transferred data.
 bool OffloadDescriptor::send_noncontiguous_pointer_data(
     int i,
     PtrData* src_data,
@@ -2915,10 +2915,10 @@ bool OffloadDescriptor::compute()
     return true;
 }
 
 // recieve pointer data if source or destination or both of them are
 // noncontiguous. There is guarantee that length of destination enough for
-// transfered data.
-bool OffloadDescriptor::recieve_noncontiguous_pointer_data(
+// transferred data.
+bool OffloadDescriptor::receive_noncontiguous_pointer_data(
     int i,
     char* base,
     COIBUFFER dst_buf,
@@ -2928,7 +2928,7 @@ bool OffloadDescriptor::recieve_nonconti
     int64_t offset_src, offset_dst;
     int64_t length_src, length_dst;
     int64_t length_src_cur, length_dst_cur;
-    int64_t recieve_size, data_recieved = 0;
+    int64_t receive_size, data_received = 0;
     COIRESULT res;
     bool dst_is_empty = true;
     bool src_is_empty = true;
@@ -2939,10 +2939,10 @@ bool OffloadDescriptor::recieve_nonconti
     length_dst = !m_vars[i].into ? length_src :
                      (m_vars_extra[i].read_rng_dst) ?
                      m_vars_extra[i].read_rng_dst->range_size : m_vars[i].size;
-    recieve_size = (length_src < length_dst) ? length_src : length_dst;
+    receive_size = (length_src < length_dst) ? length_src : length_dst;
 
     // consequently get contiguous ranges,
-    // define corresponded destination offset and recieve data
+    // define corresponded destination offset and receive data
     do {
         // get sorce offset
         if (src_is_empty) {
@@ -2953,7 +2953,7 @@ bool OffloadDescriptor::recieve_nonconti
                     break;
                 }
             }
-            else if (data_recieved == 0) {
+            else if (data_received == 0) {
                 offset_src = 0;
             }
             else {
@@ -2964,9 +2964,9 @@ bool OffloadDescriptor::recieve_nonconti
         else {
             // if source is contiguous or its contiguous range is greater
             // than destination one
-            offset_src += recieve_size;
+            offset_src += receive_size;
         }
-        length_src_cur -= recieve_size;
+        length_src_cur -= receive_size;
         src_is_empty = length_src_cur == 0;
 
         // get destination offset
@@ -2995,9 +2995,9 @@ bool OffloadDescriptor::recieve_nonconti
         else {
             // if destination is contiguous or its contiguous range is greater
             // than source one
-            offset_dst += recieve_size;
+            offset_dst += receive_size;
         }
-        length_dst_cur -= recieve_size;
+        length_dst_cur -= receive_size;
         dst_is_empty = length_dst_cur == 0;
 
         if (dst_buf != 0) {
@@ -3008,7 +3008,7 @@ bool OffloadDescriptor::recieve_nonconti
                 m_vars[i].offset + offset_src +
                 m_vars[i].mic_offset -
                 m_vars_extra[i].src_data->alloc_disp,
-                recieve_size,
+                receive_size,
                 COI_COPY_UNSPECIFIED,
                 m_in_deps_total,
                 m_in_deps_total > 0 ? m_in_deps : 0,
@@ -3028,7 +3028,7 @@ bool OffloadDescriptor::recieve_nonconti
                 m_vars[i].mic_offset -
                 m_vars_extra[i].src_data->alloc_disp,
                 base + offset_dst,
-                recieve_size,
+                receive_size,
                 COI_COPY_UNSPECIFIED,
                 m_in_deps_total,
                 m_in_deps_total > 0 ? m_in_deps : 0,
@@ -3041,7 +3041,7 @@ bool OffloadDescriptor::recieve_nonconti
                 report_coi_error(c_buf_read, res);
             }
         }
-        data_recieved += recieve_size;
+        data_received += receive_size;
     }
     while (true);
     return true;
@@ -3095,7 +3095,7 @@ bool OffloadDescriptor::receive_pointer_
 
                     if (m_vars[i].flags.is_noncont_src ||
                         m_vars[i].flags.is_noncont_dst) {
-                        recieve_noncontiguous_pointer_data(
+                        receive_noncontiguous_pointer_data(
                             i, base, dst_buf, event);
                     }
                     else if (dst_buf != 0) {
@@ -3209,7 +3209,7 @@ bool OffloadDescriptor::receive_pointer_
 
                     if (m_vars[i].flags.is_noncont_src ||
                         m_vars[i].flags.is_noncont_dst) {
-                        recieve_noncontiguous_pointer_data(
+                        receive_noncontiguous_pointer_data(
                             i, base, dst_buf, event);
                     }
                     else if (dst_buf != 0) {
@@ -3513,7 +3513,7 @@ bool OffloadDescriptor::gen_var_descs_fo
 
     ap = static_cast<const arr_desc*>(vd3->ptr_array);
 
-    // "pointers_number" for total number of transfered pointers.
+    // "pointers_number" for total number of transferred pointers.
     // For each of them we create new var_desc and put it at the bottom
     // of the var_desc's array
     get_arr_desc_numbers(ap, sizeof(void *), ptr.offset, ptr.size,
@@ -4241,7 +4241,7 @@ extern "C" void __offload_register_image
 
         case ET_DYN:
             // Registration code for libraries is called from the DllMain
-            // context (on windows) and thus we cannot do anything usefull
+            // context (on windows) and thus we cannot do anything useful
             // here. So we just add it to the list of pending libraries for
             // the later use.
             __target_libs_lock.lock();
@@ -2915,10 +2915,10 @@ bool OffloadDescriptor::compute()
 }
 
-// recieve pointer data if source or destination or both of them are
+// receive pointer data if source or destination or both of them are
 // noncontiguous. There is guarantee that length of destination enough for

Modified: openmp/trunk/offload/src/offload_host.h
URL: http://llvm.org/viewvc/llvm-project/openmp/trunk/offload/src/offload_host.h?rev=209995&r1=209994&r2=209995&view=diff
==============================================================================